@@ -12,7 +12,7 @@ sub config_path
 {
   my $path = $CONFIGFILE;
   
-  my $root = $ENV{DOCUMENT_ROOT} || fastcwd();
+  my $root = do { ($ENV{REMOTE_ADDR} || '') eq '' ? fastcwd() : $ENV{DOCUMENT_ROOT} || fastcwd() };
   
   # Try test dir:
   if( -f "$root/t/conf/$CONFIGFILE" )
